==> poste-online-0.1.tar.gz: poste-online-0.1/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


# class TestRunner(test):
#     def run(self, *args, **kwargs):
#         if self.distribution.install_requires:
#             self.distribution.fetch_build_eggs(
#                 self.distribution.install_requires)
#         if self.distribution.tests_require:
#             self.distribution.fetch_build_eggs(
#                 self.distribution.tests_require)
#         from poste.tests.runtests import runtests
#         runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='poste-online',
    version = "0.1",
    description='Poste Online', 
    author='ThunderSystems',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
     ],
#    test_suite = "poste.tests",
    setup_requires = ['nose'],
#    test_suite = 'nose.collector',
    #cmdclass={"test": TestRunner},
    install_requires = ['setuptools', 'suds-philpem'],
    package_data=get_data_files('poste')
)

==> poste-online-0.3.tar.gz: poste-online-0.3/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
# from setuptools.command.test import test


# class TestRunner(test):
#     def run(self, *args, **kwargs):
#         if self.distribution.install_requires:
#             self.distribution.fetch_build_eggs(
#                 self.distribution.install_requires)
#         if self.distribution.tests_require:
#             self.distribution.fetch_build_eggs(
#                 self.distribution.tests_require)
#         from poste.tests.runtests import runtests
#         runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|crt)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'):
                    del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    f = open('/tmp/data.txt', 'w')
    f.write(repr(data_dict))
    f.close()
    return data_dict


setup(
    name='poste-online',
    version="0.3",
    description='Poste Online',
    author='Thux',
    author_email='dev@thux.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    # test_suite = "poste.tests",
    setup_requires=['nose'],
    # test_suite = 'nose.collector',
    # cmdclass={"test": TestRunner},
    install_requires=['setuptools', 'zeep'],
    include_package_data=True,
    package_data=get_data_files('poste')
)
